Documentation
¶
Overview ¶
Kafka Client.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
Config *Config
// contains filtered or unexported fields
}
Kafka Client(Consumer/SyncProducer/AsyncProducer)
func (*Client) Receive ¶
Receive message from kafka from specified topics in config, in BLOCKING way, gkafka will handle offset tracking automatically.
type Config ¶
type Config struct {
GroupId string // group id for consumer.
Servers string // server list, multiple servers joined by ','.
Topics string // topic list, multiple topics joined by ','.
AutoMarkOffset bool // auto mark message read after consumer message from server
sarama.Config
}
kafka Client based on sarama.Config
Click to show internal directories.
Click to hide internal directories.